# World Anvil API Python Client

The World Anvil API provides endpoints to interact with the World Anvil data base.

[API Documentation](https://www.worldanvil.com/api/aragorn/documentation)

## Usage

This library can be used either by accessing the json data returned by the 
api client or use the class wrapper with properties and access points.